# shogun
Opinionated Typed Configuration

## WIP
Still working on basic functionality

Initial implementation courtesy of https://github.com/roee30/datargs
under the MIT license - maintained in this repository at LICENSE-datargs
